<?php
if(!defined('ROOT')) die();

###### Déclaration
define('BLOG_DATAPATH', ROOT.'data/plugin/blog/');
define('BLOG_PLUGINPATH', ROOT.'plugin/blog/');
define('BLOG_POSTS', BLOG_DATAPATH.'posts/');
define('BLOG_COMMENTS', BLOG_DATAPATH.'comments/');
define('BLOG_CATEGORIES', BLOG_DATAPATH.'categories/');
define('BLOG_ATOM', BLOG_DATAPATH.'atom/');

###### Classes
require_once(BLOG_PLUGINPATH.'lib/blog.class.php');
require_once(BLOG_PLUGINPATH.'lib/blogPost.class.php');
require_once(BLOG_PLUGINPATH.'lib/blogComment.class.php');
require_once(BLOG_PLUGINPATH.'lib/blogCategory.class.php');
require_once(BLOG_PLUGINPATH.'lib/blogIndex.class.php');

###### Installation
function blogInstall() {
	$index = array('current' => 0, 'published' => array(), 'all' => array());
	
	if (!is_dir(BLOG_POSTS)) {
		mkdir(BLOG_POSTS);
		if (!is_file(BLOG_POSTS.'index.json')) {
			utilWriteJsonFile(BLOG_POSTS.'index.json', $index);
		}
	}
	
	if (!is_dir(BLOG_COMMENTS)) {
		mkdir(BLOG_COMMENTS);
		if (!is_file(BLOG_COMMENTS.'index.json')) {
			utilWriteJsonFile(BLOG_COMMENTS.'index.json', $index);
		}
	}

	if (!is_dir(BLOG_CATEGORIES)) {
		mkdir(BLOG_CATEGORIES);
		if (!is_file(BLOG_CATEGORIES.'index.json')) {
			utilWriteJsonFile(BLOG_CATEGORIES.'index.json', $index);
		}
	}
	
// Upgrade to 0.5
	$data = utilScanDir(BLOG_DATAPATH, array('posts', 'comments', 'categories', 'atom', 'config.txt'));
	if (count($data['file']) > 0 || count($data['dir']) > 0) {
		// Make archive to save data
		$zip = new ZipArchive();
		$filename = 'blog_save_'.blog::formatDate(time()).'.zip';
		if ($zip->open(ROOT.'data/plugin/'.$filename, ZipArchive::CREATE) === true) {
			$files = utilScanDir(BLOG_DATAPATH);
			foreach ($files['file'] as $file) {
				$zip->addFile(BLOG_DATAPATH.$file, 'blog/'.$file);
			}
			foreach ($files['dir'] as $dir) {
				$tmp = utilScanDir(BLOG_DATAPATH.$dir.'/');
				foreach ($tmp['file'] as $file) {
					$zip->addFile(BLOG_DATAPATH.$dir.'/'.$file, 'blog/'.$dir.'/'.$file);
				}
			}
			$zip->close();
		} else {
			return false;
		}
		
		if (is_file(BLOG_DATAPATH.'categories.json')) {
			$categories = utilReadJsonFile(BLOG_DATAPATH.'categories.json');
			
			$index = array(
				'current' => 0,
				'published' => array(),
				'all' => array()
			);
			
			foreach ($categories as $category) {
				$data = utilReadJsonFile(BLOG_CATEGORIES.$category['id'].'.json');
				
				$id = $category['id'];
				unset($category['id']);
				
				$category['nbPosts'] = $category['nb'];
				unset($category['nb']);
				
				$category['posts'] = $data;
				
				utilWriteJsonFile(BLOG_CATEGORIES.$id.'.json', $category);
				
				$index['current'] += 1;
				$index['all'][] = $id;
			}
			
			utilWriteJsonFile(BLOG_CATEGORIES.'index.json', $index);
			
			unlink(BLOG_DATAPATH.'categories.json');
		}
		
		if (is_file(BLOG_DATAPATH.'index.json')) {
			$index = utilReadJsonFile(BLOG_DATAPATH.'index.json');
			$index['current'] = max($index['all']) + 1;
			
			$newcommentsindex = utilReadJsonFile(BLOG_COMMENTS.'index.json');
			
			foreach ($index['all'] as $id) {
				$post = utilReadJsonFile(BLOG_DATAPATH.$id.'.txt');
				
				unset($post['id']);
				
				if (!is_numeric($post['date'])) {
					$post['date'] = blog::formatDate($post['date'], true);
				}
				
				$post['comments'] = array(
					'published' => array(),
					'all' => array()
				);
				
				$commentsIndex = utilReadJsonFile(BLOG_DATAPATH.$id.'/index.json');
				
				foreach ($commentsIndex['all'] as $cid) {
					$comment = utilReadJsonFile(BLOG_DATAPATH.$id.'/'.$cid.'.txt');
					
					unset($comment['id']);
					
					$comment['post'] = $id;
					
					if (!is_numeric($comment['date'])) {
						$comment['date'] = blog::formatDate($comment['date'], true);
					}
					
					$post['comments']['all'][] = $newcommentsindex['current'];
					$newcommentsindex['all'][] = $newcommentsindex['current'];
					if ($comment['published']) {
						$post['comments']['published'][] = $newcommentsindex['current'];
						$newcommentsindex['published'][] = $newcommentsindex['current'];
					}
					
					utilWriteJsonFile(BLOG_COMMENTS.$newcommentsindex['current'].'.json', $comment);
					$newcommentsindex['current'] += 1;
					
					unlink(BLOG_DATAPATH.$id.'/'.$cid.'.txt');
				}
				
				utilWriteJsonFile(BLOG_POSTS.$id.'.json', $post);
				
				if (is_file(BLOG_DATAPATH.$id.'/index.json')) {
					unlink(BLOG_DATAPATH.$id.'/index.json');
				}
				rmdir(BLOG_DATAPATH.$id);
				unlink(BLOG_DATAPATH.$id.'.txt');
			}
			
			utilWriteJsonFile(BLOG_COMMENTS.'index.json', $newcommentsindex);
			utilWriteJsonFile(BLOG_POSTS.'index.json', $index);
			
			unlink(BLOG_DATAPATH.'index.json');
		} else {
			foreach ($data['file'] as $file) {
				unlink(BLOG_DATAPATH.$file);
			}
		}
	}
// -- End of Upgrade
	
	if (!is_dir(BLOG_ATOM)) {
		mkdir(BLOG_ATOM);
	}
	file_put_contents(BLOG_ATOM.'.htaccess', 'allow from all');
	include_once(BLOG_PLUGINPATH.'atom.php');
}

###### Hooks
function blogHookLinkAtom() {
	$temp = "echo \"\\n\\t\".'<link rel=\"alternate\" type=\"application/atom+xml\" title=\"'.\$data['siteName'].'\" href=\"'.\$data['siteUrl'].'/data/plugin/blog/atom/blog.atom\" />'.\"\\n\";";
	return $temp;
}

###### Navigation
if ($coreConf['defaultPlugin'] == 'blog') {
	$pluginsManager->getPlugin('blog')->addToNavigation(pluginsManager::getPluginConfVal('blog', 'title'), $coreConf['siteUrl']);
} else {
	$pluginsManager->getPlugin('blog')->addToNavigation(pluginsManager::getPluginConfVal('blog', 'title'), rewriteUrl('blog'));
}

?>
