<?php

/*
To be implemented :
	+ migration process
		- save
		- convert
		- make a lot of verifications
		- abort and restore on any failure
		- move data only after main verifications
*/

class blog {
	public static function createPost($title, $author, $content, $date = -1, $published = false, $category = -1) {
		if ($date == -1) {
			$date = time();
		}
		
		$post = new blogPost();
		$post->setTitle($title);
		$post->setAuthor($author);
		$post->setContent($content);
		$post->setDate($date);
		$post->setPublished($published);
		$post->setCategory($category);
		$post->save();
		
		if ($category != -1) {
			$category = blog::getCategory($category);
			$category->addPost($post, $published, true);
			$category->save();
		}
		
		blog::addToIndex($post, 'posts', $published);
		
		return $post;
	}
	
	public static function createComment($author, $content, $post = -1, $date = -1, $published = true) {
		if ($date == -1) {
			$date = time();
		}
		
		$comment = new blogComment();
		$comment->setAuthor($author);
		$comment->setContent($content);
		$comment->setDate($date);
		$comment->setPublished($published);
		$comment->setPost($post);
		$comment->save();
		
		blog::addToIndex($comment, 'comments', $published);
		
		return $comment;
	}
	
	public static function createCategory($label) {
		$category = new blogCategory();
		$category->setLabel($label);
		$category->save();
		
		blog::addToIndex($category, 'categories', false);
		
		return $category;
	}
	
	public static function createTag() {
	
	}
	
	public static function getPage($number, $published = true) {
		$nbPosts = pluginsManager::getPluginConfVal('blog', 'entry_per_page');
		$index = blog::getIndex('posts');
		$index = $index->getElements($published);
		$posts = array();		
		
		for ($i = ($number - 1) * $nbPosts; $i < min($number * $nbPosts, count($index)); $i += 1) {
			$posts[] = $index[$i];
		}
		
		return $posts;
	}
	
	public static function getCategoryPage($id, $number, $published = true) {
		$nbPosts = pluginsManager::getPluginConfVal('blog', 'entry_per_page');
		$category = blog::getCategory($id);
		$index = $category->getPosts($published);
		$posts = array();
		
		for ($i = ($number - 1) * $nbPosts; $i < min($number * $nbPosts, count($index)); $i += 1) {
			$posts[] = $index[$i];
		}
		
		return $posts;
	}
	
	public static function getPost($id, $comments = true) {
		return new blogPost($id, $comments);
	}

	public static function getPosts($published = true) {
		$index = blog::getIndex('posts');

		$posts = $index->getElements($published);
		
		return $posts;
	}
	
	public static function getComment($id) {
		return new blogComment($id);
	}
	
	public static function getCategory($id, $posts = true) {
		return new blogCategory($id, $posts);
	}
	
	public static function getCategories() {
		$index = blog::getIndex('categories');
		
		$categories = $index->getAll();
		
		return $categories;
	}
	
	public static function getTag() {
		
	}
	
	public static function getIndex($type) {
		return new blogIndex($type);
	}
	
	public static function hasNextPage($number, $published = true, $type = 'page', $id = -1) {
		if ($type == 'page') {
			$index = blog::getIndex('posts');
			$posts = $index->getElements($published);

			return count($posts) > $number * pluginsManager::getPluginConfVal('blog', 'entry_per_page');
		} else if ($type == 'category') {
			if ($id != -1) {
				$index = blog::getCategory($id);
				$posts = $index->getPosts($published);

				return count($posts) > $number * pluginsManager::getPluginConfVal('blog', 'entry_per_page');
			}
		}
		
		return false;
	}
	
	public static function hasPreviousPage($number) {
		return $number > 1;
	}
	
	public static function order($elements, $reverse = false) {
		$tmp = array();
		$type = '';
		
		if (isset($elements[0])) {
			if (method_exists($elements[0], 'getDate')) {
				$type = 'date';
			} else if (method_exists($elements[0], 'getLabel')) {
				$type = 'label';
			}
		}
		
		foreach ($elements as $element) {
			if ($type == 'date') {
				$tmp[] = $element->getDate();
			} else if ($type == 'label') {
				$tmp[] = $element->getLabel();
			}
		}
		
		if ($type == 'date') {
			if ($reverse) {
				array_multisort($tmp, SORT_ASC, $elements);
			} else {
				array_multisort($tmp, SORT_DESC, $elements);
			}
		} else if ($type == 'label') {
			if ($reverse) {
				array_multisort($tmp, SORT_DESC, $elements);
			} else {
				array_multisort($tmp, SORT_ASC, $elements);
			}
		}
		
		return $elements;
	}
	
	public static function orderIndex($type) {
		$index = blog::getIndex($type);
		$index->orderElements();
		$index->save();
	}
	
	public static function orderCategory($id) {
		$category = blog::getCategory($id);
		$category->orderPosts();
		$category->save();
	}
	
	public static function deletePost($id) {
		$post = blog::getPost($id);
		
		blog::removeFromIndex($id, 'posts');
		
		if ($post->getCategory() != -1) {
			$category = blog::getCategory($post->getCategory());
			$category->removePost($id);
			$category->save();
		}
		
		foreach ($post->getComments() as $comment) {
			blog::deleteComment($comment->getId());
		}
		
		if (is_file(BLOG_POSTS.$id.'.json')) {
			unlink(BLOG_POSTS.$id.'.json');
		}
	}
	
	public static function deleteComment($id) {
		$comment = blog::getComment($id);
		
		blog::removeFromIndex($id, 'comments');
		
		$post = blog::getPost($comment->getPost());
		$post->removeComment($id);
		$post->save();
		
		if (is_file(BLOG_COMMENTS.$id.'.json')) {
			unlink(BLOG_COMMENTS.$id.'.json');
		}
	}
	
	public static function deleteCategory($id, $posts = false) {
		$category = blog::getCategory($id);
		
		if ($posts) {
			foreach ($category->getPosts() as $post) {
				blog::deletePost($post->getId());
			}
		} else {
			foreach ($category->getPosts() as $post) {
				$post->setCategory(-1);
				$post->save();
			}
		}
		
		if (is_file(BLOG_CATEGORIES.$id.'.json')) {
			unlink(BLOG_CATEGORIES.$id.'.json');
		}
	}
	
	public static function deleteTag() {
	
	}
	
	public static function addToIndex($element, $index, $published = true) {
		$index = new blogIndex($index);
		$index->addElement($element, $published);
		$index->save();
	}
	
	public static function removeFromIndex($id, $index) {
		$index = new blogIndex($index);
		$index->removeElement($id);
		$index->save();
	}
	
	public static function useCaptcha() {
		return pluginsManager::getPluginConfVal('blog', 'captcha') && blog::captchaIsActive();
	}
	
	public static function captchaIsActive() {
		return pluginsManager::isActivePlugin('captcha');
	}
	
	public static function formatDate($date, $reverse = false) {
		if ($reverse) {
			$timestamp = 0;

		// format composé du plugin blog : 23.12.2011 - 15:44
			$year = substr($date, 6, 4);
			$month = substr($date, 3, 2);
			$day = substr($date, 0, 2);
			$hour = substr($date, 13, 2);
			$minute = substr($date, 16, 2);
			$seconds = '00';
	
		// format composé MySQL utilisé : 2008-08-17 18:11:31
			$composed = $year.'-'.$month.'-'.$day.' '.$hour.':'.$minute.':'.$seconds;
	
			$timestamp = strtotime($composed);
	
			return $timestamp;
		} else {
			$str = '';
		
			if (is_numeric($date)) {
		// format composé du plugin blog : 23.12.2011 - 15:44
				$str = date('d.m.Y - H:i', $date);
			}
		
			return $str;
		}
	}
}

?> 
