<?php

class blogCategory {
	private $id;
	private $label;
	private $nbPosts;
	private $posts;
	
	public function __construct($id = -1, $posts = true) {
		$this->id = $id;
		if ($this->id == -1) {
			$this->label = '';
			$this->nbPosts = 0;
			$this->posts = array(
				'published' => array(),
				'all' => array()
			);
		} else {
			$category = utilReadJsonFile(BLOG_CATEGORIES.$this->id.'.json');
			$this->label = $category['label'];
			$this->nbPosts = $category['nbPosts'];
			$this->posts = array(
				'published' => array(),
				'all' => array()
			);
			
			if ($posts) {
				foreach ($category['posts']['published'] as $post) {
					$this->posts['published'][] = blog::getPost($post);
				}
				foreach ($category['posts']['all'] as $post) {
					$this->posts['all'][] = blog::getPost($post);
				}
			}
		}
	}
	
	public function getId() {
		return $this->id;
	}
	
	public function getLabel() {
		return $this->label;
	}
	
	public function getNbPosts() {
		return $this->nbPosts;
	}
	
	public function getPosts($published = true) {
		if ($published) {
			return $this->posts['published'];
		} else {
			return $this->posts['all'];
		}
	}
	
	public function setLabel($label) {
		$this->label = trim($label);
	}
	
	public function setNbPosts($nbPosts) {
		$this->nbPosts = $nbPosts;
	}
	
	public function orderPosts() {
		$this->posts['published'] = blog::order($this->posts['published']);
		$this->posts['all'] = blog::order($this->posts['all']);
	}
	
	public function addPost($post, $published = true, $new = false) {
		if ($published) {
			$this->posts['published'][] = $post;
			$this->posts['published'] = blog::order($this->posts['published']);
			$this->posts['all'][] = $post;
			$this->posts['all'] = blog::order($this->posts['all']);
		} else {
			$this->posts['all'][] = $post;
			$this->posts['all'] = blog::order($this->posts['all']);
		}
		
		if ($new) {
			$this->nbPosts += 1;
		}
	}
	
	public function removePost($id) {
		$found = false;
		foreach ($this->posts['published'] as $index=>$post) {
			if ($post->getId() == $id) {
				unset($this->posts['published'][$index]);
				$found = true;
				break;
			}
		}
		if ($found) {
			$this->posts['published'] = array_values($this->posts['published']);
			$found = false;
		}
		foreach ($this->posts['all'] as $index=>$post) {
			if ($post->getId() == $id) {
				unset($this->posts['all'][$index]);
				$found = true;
				break;
			}
		}
		if ($found) {
			$this->posts['all'] = array_values($this->posts['all']);
			$this->nbPosts -= 1;
		}

		return $found;
	}
	
	public function hydratePosts() {
		$category = utilReadJsonFile(BLOG_CATEGORIES.$this->id.'.json');
		$this->posts = array(
			'published' => array(),
			'all' => array()
		);
		
		foreach ($category['posts']['published'] as $post) {
			$this->posts['published'][] = blog::getPost($post);
		}
		foreach ($category['posts']['all'] as $post) {
			$this->posts['all'][] = blog::getPost($post);
		}
	}
	
	public function publishPost($id) {
		$this->posts['published'][] = blog::getPost($id);
		$this->posts['published'] = blog::order($this->posts['published']);
		$this->nbPosts += 1;
	}
	
	public function unpublishPost($id) {
		foreach ($this->posts['published'] as $index=>$post) {
			if ($post->getId() == $id) {
				unset($this->posts['published'][$index]);
				$this->nbPosts -= 1;
				break;
			}
		}
		$this->posts['published'] = array_values($this->posts['published']);
	}
	
	public function save() {
		$category = array(
			'label' => $this->label,
			'nbPosts' => $this->nbPosts,
			'posts' => array(
				'published' => array(),
				'all' => array()
			)
		);
		
		foreach ($this->posts['published'] as $post) {
			$category['posts']['published'][] = $post->getId();
		}
		foreach ($this->posts['all'] as $post) {
			$category['posts']['all'][] = $post->getId();
		}
		
		if ($this->id == -1) {
			$index = utilReadJsonFile(BLOG_CATEGORIES.'index.json');
			$this->id = $index['current'];
			$index['current'] += 1;
			utilWriteJsonFile(BLOG_CATEGORIES.'index.json', $index);
		}
		
		return utilWriteJsonFile(BLOG_CATEGORIES.$this->id.'.json', $category);
	}
	
	public function __toString() {
		return ''.$this->label;
	}
}

?>
