<?php

class blogIndex {
	private $type;
	private $filename;
	private $current;
	private $published;
	private $all;
	
	public function __construct($type = 'posts') {
		$this->type = $type;
		$this->filename = BLOG_DATAPATH.$type.'/index.json';
		
		$index = utilReadJsonFile($this->filename);
		$this->current = $index['current'];
		$this->published = array();
		$this->all = array();
		
		if ($type == 'posts') {
			foreach ($index['published'] as $post) {
				$this->published[] = blog::getPost($post);
			}
			foreach ($index['all'] as $post) {
				$this->all[] = blog::getPost($post);
			}
		} else if ($type == 'comments') {
			foreach ($index['published'] as $comment) {
				$this->published[] = blog::getComment($comment);
			}
			foreach ($index['all'] as $comment) {
				$this->all[] = blog::getComment($comment);
			}
		} else if ($type == 'categories') {
			foreach ($index['all'] as $category) {
				$this->all[] = blog::getCategory($category);
			}
		}
	}
	
	public function getType() {
		return $this->type;
	}
	
	public function getCurrent() {
		return $this->current;
	}
	
	public function getPublished() {
		return $this->published;
	}
	
	public function getAll() {
		return $this->all;
	}
	
	public function getElements($published = true) {
		if ($published) {
			return $this->getPublished();
		} else {
			return $this->getAll();
		}
	}
	
	public function setCurrent($current) {
		$this->current = $current;
	}
	
	public function orderElements() {
		$this->published = blog::order($this->published);
		$this->all = blog::order($this->all);
	}
	
	public function addElement($element, $published = true) {
		if ($published) {
			$this->published[] = $element;
			$this->published = blog::order($this->published);
			$this->all[] = $element;
			$this->all = blog::order($this->all);
		} else {
			$this->all[] = $element;
			$this->all = blog::order($this->all);
		}
	}
	
	public function removeElement($id) {
		$found = false;
		foreach ($this->published as $index=>$element) {
			if ($element->getId() == $id) {
				unset($this->published[$index]);
				$found = true;
				break;
			}
		}
		if ($found) {
			$this->published = array_values($this->published);
			$found = false;
		}
		foreach ($this->all as $index=>$element) {
			if ($element->getId() == $id) {
				unset($this->all[$index]);
				$found = true;
				break;
			}
		}
		if ($found) {
			$this->all = array_values($this->all);
		}
		
		return $found;
	}
	
	public function publishElement($id) {
		if ($this->type != 'categories') {
			if ($this->type == 'posts') {
				$this->published[] = blog::getPost($id);
			} else if ($type == 'comments') {
				$this->published[] = blog::getComment($id);
			}
			$this->published = blog::order($this->published);
		}
	}
	
	public function unpublishElement($id) {
		if ($this->type != 'categories') {
			foreach ($this->published as $index=>$element) {
				if ($element->getId() == $id) {
					unset($this->published[$index]);
					break;
				}
			}
			$this->published = array_values($this->published);
		}
	}
	
	public function save() {
		$index = array(
			'type' => $this->type,
			'current' => $this->current,
			'published' => array(),
			'all' => array()
		);
		
		foreach ($this->published as $element) {
			$index['published'][] = $element->getId();
		}
		
		foreach ($this->all as $element) {
			$index['all'][] = $element->getId();
		}
				
		utilWriteJsonFile($this->filename, $index);
	}
}

?>
