<?php

class blogPost {
	private $id;
	private $title;
	private $author;
	private $content;
	private $date;
	private $published;
	private $category;
	private $nbComments;
	private $comments;
	
	public function __construct($id = -1, $comments = true) {
		$this->id = $id;
		if ($this->id == -1) {
			$this->title = '';
			$this->author = '';
			$this->content = '';
			$this->date = -1;
			$this->published = false;
			$this->category = -1;
			$this->nbComments = 0;
			$this->comments = array(
				'published' => array(),
				'all' => array()
			);
		} else {
			$post = utilReadJsonFile(BLOG_POSTS.$this->id.'.json');
			$this->title = $post['title'];
			$this->published = $post['published'];
			$this->date = $post['date'];
			$this->author = $post['author'];
			$this->category = $post['category'];
			$this->content = $post['content'];
			$this->nbComments = $post['nbComments'];
			$this->comments = array(
				'published' => array(),
				'all' => array()
			);
			
			if ($comments) {
				foreach ($post['comments']['published'] as $comment) {
					$this->comments['published'][] = blog::getComment($comment);
				}
				foreach ($post['comments']['all'] as $comment) {
					$this->comments['all'][] = blog::getComment($comment);
				}
			}
		}
	}
	
	public function getId() {
		return $this->id;
	}
	
	public function getTitle() {
		return $this->title;
	}
	
	public function getAuthor() {
		return $this->author;
	}
	
	public function getContent() {
		return $this->content;
	}
	
	public function getDate() {
		return $this->date;
	}
	
	public function getPublished() {
		return $this->published;
	}
	
	public function getCategory() {
		return $this->category;
	}
	
	public function getNbComments() {
		return $this->nbComments;
	}
	
	public function getComments($published = true) {
		if ($published) {
			return $this->comments['published'];
		} else {
			return $this->comments['all'];
		}
	}
	
	public function setTitle($title) {
		$this->title = trim($title);
	}
	
	public function setAuthor($author) {
		$this->author = trim($author);
	}
	
	public function setContent($content) {
		$this->content = trim($content);
	}
	
	public function setDate($date) {
		$this->date = $date;
	}
	
	public function setPublished($published) {
		$this->published = $published;
	}
	
	public function setCategory($category) {
		$this->category = $category;
	}
	
	public function setNbComments($nbComments) {
		$this->nbComments = $nbComments;
	}
	
	public function addComment($comment, $published = true, $new = false) {
		if ($published) {
			$this->comments['published'][] = $comment;
			$this->comments['published'] = blog::order($this->comments['published'], true);
			$this->comments['all'][] = $comment;
			$this->comments['all'] = blog::order($this->comments['all'], true);
		} else {
			$this->comments['all'][] = $comment;
			$this->comments['all'] = blog::order($this->comments['all'], true);
		}
		if ($new) {
			$this->nbComments += 1;
		}
	}
	
	public function removeComment($id) {
		$found = false;
		foreach ($this->comments['published'] as $index=>$comment) {
			if ($comment->getId() == $id) {
				unset($this->comments['published'][$index]);
				$found = true;
				break;
			}
		}
		if ($found) {
			$this->comments['published'] = array_values($this->comments['published']);
			$found = false;
		}
		foreach ($this->comments['all'] as $index=>$comment) {
			if ($comment->getId() == $id) {
				unset($this->comments['all'][$index]);
				$found = true;
				break;
			}
		}
		if ($found) {
			$this->comments['all'] = array_values($this->comments['all']);
			$this->nbComments -= 1;
		}
		
		return $found;
	}
	
	public function hydrateComments() {
		$post = utilReadJsonFile(BLOG_POSTS.$this->id.'.json');
		$this->comments = array(
			'published' => array(),
			'all' => array()
		);
		foreach ($post['comments']['published'] as $comment) {
			$post['comments']['published'][] = blog::getComment($comment);
		}
		foreach ($post['comments']['all'] as $comment) {
			$post['comments']['all'][] = blog::getComment($comment);
		}
	}
	
	public function publishComment($id) {
		$this->comments['published'][] = blog::getComment($id);
		$this->comments['published'] = blog::order($this->comments['published'], true);
		$this->nbComments += 1;
	}
	
	public function unpublishComment($id) {
		foreach ($this->comments['published'] as $index=>$comment) {
			if ($comment->getId() == $id) {
				unset($this->comments['published'][$index]);
				$this->nbComments -= 1;
				break;
			}
		}
		$this->comments['published'] = array_values($this->comments['published']);
	}
	
	public function publish() {
		if (!$this->published) {
			$this->published = true;
			
			$index = blog::getIndex('posts');
			$index->publishElement($this->id);
			$index->save();
			
			if ($this->category != -1) {
				$category = blog::getCategory($this->category);
				$category->publishPost($this->id);
				$category->save();
			}
			
			$this->save();
		}
	}
	
	public function unpublish() {
		if ($this->published) {
			$this->published = false;
			
			$index = blog::getIndex('posts');
			$index->unpublishElement($this->id);
			$index->save();
			
			if ($this->category != -1) {
				$category = blog::getCategory($this->category);
				$category->unpublishPost($this->id);
				$category->save();
			}
			
			$this->save();
		}
	}
	
	public function save() {
		$post = array(
			'title' => $this->title,
			'author' => $this->author,
			'content' => $this->content,
			'date' => $this->date,
			'published' => $this->published,
			'category' => $this->category,
			'nbComments' => $this->nbComments,
			'comments' => array(
				'published' => array(),
				'all' => array()
			)
		);
		
		foreach ($this->comments['published'] as $comment) {
			$post['comments']['published'][] = $comment->getId();
		}
		foreach ($this->comments['all'] as $comment) {
			$post['comments']['all'][] = $comment->getId();
		}
		
		if ($this->id == -1) {
			$index = utilReadJsonFile(BLOG_POSTS.'index.json');
			$this->id = $index['current'];
			$index['current'] += 1;
			utilWriteJsonFile(BLOG_POSTS.'index.json', $index);
		}
		
		return utilWriteJsonFile(BLOG_POSTS.$this->id.'.json', $post);
	}
}

?>
